Files
RedBear-OS/local/recipes/dev/libclc/source/clang/test/SemaCUDA/kernel-call.cu
T
vasilito cb424d7448 build: static patch-sanity linter (shift-left the malformed-patch class)
verify-patch-sanity.py validates every active recipe .patch has internally-
consistent hunk line counts — catching the 'malformed patch at line N' failure
at commit/CI/preflight time instead of hours into a cook. This cycle hit that
class three times (qtwaylandscanner, sddm, xwayland), each only discovered when
cookbook tried to apply the patch.

Running it across the repo found 29 latent malformed patches (validated against
GNU patch: e.g. relibc/P3-sysv-ipc reproduces 'malformed patch at line 22').
They were harmless only because they sit in vendored recipes (baked, not re-
applied) — but would fail on any version-bump re-derivation. --fix recounts the
hunk headers (body untouched) and repaired all 29.

Wired into build-preflight.sh (Phase 1.0D) and redbear-ci.yml, with a unit test
(test-patch-sanity.sh). Skips archived/legacy trees and unvalidatable formats
(empty placeholders, bare-@@ git hunks).
2026-08-01 05:13:02 +03:00

60 lines
1.5 KiB
Plaintext

// RUN: %clang_cc1 -fsyntax-only -verify %s
#include "Inputs/cuda.h"
__global__ void g1(int x) {}
template <typename T> void t1(T arg) {
g1<<<arg, arg>>>(1);
}
void h1(int x) {}
int h2(int x) { return 1; }
int main(void) {
g1<<<1, 1>>>(42);
g1(42); // expected-error {{call to global function 'g1' not configured}}
g1<<<1>>>(42); // expected-error {{too few execution configuration arguments to kernel function call}}
g1<<<1, 1, 0, 0, 0>>>(42); // expected-error {{too many execution configuration arguments to kernel function call}}
t1(1);
h1<<<1, 1>>>(42); // expected-error {{kernel call to non-global function 'h1'}}
int (*fp)(int) = h2;
fp<<<1, 1>>>(42); // expected-error {{must have void return type}}
g1<<<undeclared, 1>>>(42); // expected-error {{use of undeclared identifier 'undeclared'}}
}
// Make sure we can call static member kernels.
template <typename > struct a0 {
template <typename T> static __global__ void Call(T);
};
struct a1 {
template <typename T> static __global__ void Call(T);
};
template <typename T> struct a2 {
static __global__ void Call(T);
};
struct a3 {
static __global__ void Call(int);
static __global__ void Call(void*);
};
struct b {
template <typename c> void d0(c arg) {
a0<c>::Call<<<0, 0>>>(arg);
a1::Call<<<0,0>>>(arg);
a2<c>::Call<<<0,0>>>(arg);
a3::Call<<<0, 0>>>(arg);
}
void d1(void* arg) {
a0<void*>::Call<<<0, 0>>>(arg);
a1::Call<<<0,0>>>(arg);
a2<void*>::Call<<<0,0>>>(arg);
a3::Call<<<0, 0>>>(arg);
}
void e() { d0(1); }
};